# Third Party Licenses

## Web Interface

  * [Babel JavaScript Support](https://github.com/mitsuhiko/babel/blob/master/contrib/babel.js): BSD
  * [@babel/polyfill](https://babeljs.io/docs/en/babel-polyfill/): MIT
  * [Bootstrap](http://getbootstrap.com/): Apache License 2.0
  * [Bootstrap Modal](http://jschr.github.io/bootstrap-modal/): Apache License 2.0
  * [Bootstrap Slider Knockout Binding](https://github.com/cosminstefanxp/bootstrap-slider-knockout-binding): MIT
  * [Bootstrap Slider](http://seiyria.com/bootstrap-slider/): Apache License 2.0
  * [Bootstrap Tabdrop](http://www.eyecon.ro/bootstrap-tabdrop): Apache License 2.0
  * [css-element-queries](https://github.com/marcj/css-element-queries): MIT
  * [Detect Mobile Browser](http://detectmobilebrowsers.com/): Public Domain
  * [Flot](http://www.flotcharts.org/): MIT
  * [HLS.js](https://github.com/video-dev/hls.js): Apache License 2.0
  * [JavaScript MD5](https://github.com/blueimp/JavaScript-MD5): MIT
  * [JQuery](http://jquery.com/): MIT
  * [JQuery Bootstrap Wizard](http://github.com/VinceG/twitter-bootstrap-wizard): MIT, GPL (dual licensed)
  * [JQuery File Upload](https://github.com/blueimp/jQuery-File-Upload): MIT
  * [JQuery iframe transport](https://github.com/blueimp/jQuery-File-Upload/blob/master/js/jquery.iframe-transport.js): MIT
  * [JQuery QRCode](http://larsjung.de/jquery-qrcode/): MIT
  * [JQuery Slimscroll](http://rocha.la/jQuery-slimScroll): MIT, GPL (dual licensed)
  * [JQuery UI Core, Mouse, Slider and Widget](http://jqueryui.com): MIT
  * [Knockout](http://knockoutjs.com/): MIT
  * [LESS](http://lesscss.org): Apache License 2.0
  * [lodash](https://lodash.com): MIT
  * [Loglevel](https://github.com/pimterry/loglevel): MIT
  * [md5.js](https://blueimp.github.io/JavaScript-MD5/): MIT
  * [Modernizr](http://modernizr.com): MIT
  * [Moment.js](http://momentjs.com/): MIT
  * [PNotify](http://sciactive.com/pnotify/): GPL, LGPL, MPL (triple licensed)
  * [pusher.color.js](http://cache.preserve.io/5g18q0pw/index.html) (original link dead): MIT
  * [SockJS](https://github.com/sockjs/sockjs-client): MIT
  * [sprintf-js](http://alexei.ro/): BSD
  * [UAParser.js](https://faisalman.github.io/ua-parser-js/): MIT

## Server

  * [appdirs](http://github.com/ActiveState/appdirs): MIT
  * [Awesome-Slugify](https://pypi.python.org/pypi/awesome-slugify): GPLv3
  * [chainmap](https://bitbucket.org/jeunice/chainmap): Python
  * [Click](http://click.pocoo.org/): BSD
  * [emoji](https://github.com/carpedm20/emoji/): BSD
  * [feedparser](https://github.com/kurtmckee/feedparser): BSD
  * [filetype](https://h2non.github.io/filetype.py/): MIT
  * [Flask](http://flask.pocoo.org/): BSD
  * [Flask-Assets](http://github.com/miracle2k/flask-assets): BSD
  * [Flask-Babel](http://github.com/mitsuhiko/flask-babel): BSD
  * [Flask-Login](https://github.com/maxcountryman/flask-login): MIT
  * [Flask-Markdown](http://github.com/dcolish/flask-markdown): BSD
  * [Flask-Principal](http://packages.python.org/Flask-Principal/): MIT
  * [frozendict](https://github.com/slezica/python-frozendict): MIT
  * [future](https://python-future.org/): MIT
  * [futures](https://github.com/agronholm/pythonfutures): Python
  * [monotonic](https://github.com/atdt/monotonic): Apache License 2.0
  * [netaddr](https://github.com/drkjam/netaddr/): BSD
  * [netifaces](https://bitbucket.org/al45tair/netifaces): MIT
  * [pathvalidate](https://pathvalidate.readthedocs.io/en/latest/index.html): MIT
  * [pkginfo](http://pypi.python.org/pypi/pkginfo/): Python
  * [psutil](https://github.com/giampaolo/psutil): BSD
  * [pylru](https://github.com/jlhutch/pylru): GPLv2
  * [pyserial](http://pyserial.sourceforge.net/): Python
  * [PyYAML](http://pyyaml.org/wiki/PyYAML): MIT
  * [requests](http://python-requests.org/): Apache License 2.0
  * [rsa](http://stuvel.eu/rsa): Apache License 2.0
  * [sarge](http://sarge.readthedocs.org/): BSD
  * [sentry-sdk](https://github.com/getsentry/sentry-python): BSD
  * [scandir](https://github.com/benhoyt/scandir): BSD
  * [semantic_version](https://github.com/rbarrois/python-semanticversion): BSD
  * [SockJS-Tornado](http://github.com/mrjoes/sockjs-tornado/): MIT
  * [Tornado](http://www.tornadoweb.org/): Apache License 2.0
  * [typing](https://pypi.org/project/typing/): Python
  * [watchdog](http://github.com/gorakhargosh/watchdog): Apache License 2.0
  * [websocket-client](https://github.com/liris/websocket-client): LGPLv3
  * [wrapt](http://wrapt.readthedocs.org/): BSD
  * [zipstream-ng](https://github.com/pR0Ps/zipstream-ng): LGPLv3

## Development (testing, documentation generation, etc)

  * [cookiecutter](https://github.com/cookiecutter/cookiecutter): BSD
  * [ddt](https://github.com/txels/ddt): MIT
  * [flake8](https://gitlab.com/pycqa/flake8): MIT
  * [mock](https://github.com/testing-cabal/mock): BSD
  * [pyinstrument](https://github.com/joerick/pyinstrument): BSD
  * [pytest](https://docs.pytest.org/en/latest/): MIT
  * [pytest-doctest-custom](http://github.com/danilobellini/pytest-doctest-custom): MIT
  * [Sphinx](http://sphinx-doc.org/): BSD
  * [sphinxcontrib-httpdomain](https://bitbucket.org/birkenfeld/sphinx-contrib/src/default/httpdomain/): BSD
  * [sphinxcontrib-mermad](https://github.com/mgaitan/sphinxcontrib-mermaid): BSD
  * [sphinx_rtd_theme](https://github.com/snide/sphinx_rtd_theme/): BSD
